@@ -32,10 +32,10 @@ echo ""
 #プラットフォームをチェック
 if [ ${PLATFORM} = "linux" ]; then
 	EXEC_USER=`/usr/bin/whoami`
-	PS="ps -ef"
+	
 elif [ ${PLATFORM} = "solaris" ]; then
 	EXEC_USER=`/usr/ucb/whoami`
-	PS="/usr/ucb/ps auxwww"
+		
 else
 	echo ""
 	echo "ERROR 環境変数PLATFORMの値が不正です。"
@@ -556,13 +556,6 @@ do
 						# コピー開始
 						echo "必要なファイルのコピーを開始します。"
 						cp -pr $EXEC_PATH/hinemos_agent /opt
-						mkdir /${HINEMOS_AGENT_HOME}/sbin
-						cp -pr $EXEC_PATH/install.cfg ${HINEMOS_AGENT_HOME}/sbin
-						cp -pr $EXEC_PATH/agent_installer_EN.sh ${HINEMOS_AGENT_HOME}/sbin
-						cp -pr $EXEC_PATH/agent_installer_JP.sh ${HINEMOS_AGENT_HOME}/sbin
-						cp -pr $EXEC_PATH/service ${HINEMOS_AGENT_HOME}/sbin
-						cp -pr $EXEC_PATH/sbin/* ${HINEMOS_AGENT_HOME}/sbin
-						
 						
 						#install.cfgの内容を反映してhinemos_agent.cfgをコピー
 						REPLACE_PATH=`echo ${JRE_NAME} | sed 's/\//\\\\\//g'`
@@ -647,10 +640,12 @@ do
 			case ${ANS} in
 				y|Y)
 					#プロセス終了の確認
-					${PS} | grep /agent/ | grep -v grep | grep hinemos > /dev/null
+					#ps axu | grep /agent/ | grep -v grep | grep hinemos > /dev/null
+					ps -ef | grep /agent/ | grep -v grep | grep hinemos > /dev/null
 	  				RET1=$?  
 
-	  				${PS} | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
+	  				#ps axu | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
+	  				ps -ef | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
 	  				RET2=$?  
 				
 					if [ ${RET1} -eq 0 -o ${RET2} -eq 0 ]; then
